unittest.TestSuite

unittest :: TestSuite :: Class TestSuite |
[hide private]
[frames] | no frames]

# Class TestSuite

source code

    object --+
             |
            TestSuite

A test suite is a composite test consisting of a number of TestCases.

For use, create an instance of TestSuite, then add test case instances. When all tests have been added, the suite can be passed to a test runner, such as TextTestRunner. It will run the individual test cases in the order in which they were added, aggregating the results. When subclassing, do not forget to call the base class constructor.

Instance Methods | [hide private]
__call__(self, *args, **kwds) | source code
__init__(self, tests=`(``)`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__iter__(self) | source code
__repr__(self) str(x) | source code
__str__(self) str(x) | source code
addTest(self, test) | source code
addTests(self, tests) | source code
countTestCases(self) | source code
debug(self) Run the tests without collecting errors in a TestResult | source code
run(self, result) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, tests=`(``)`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
str(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)